//******************************************************************************
//
// File:    SurveyUI.java
// Package: edu.rit.survey
// Unit:    Class edu.rit.survey.SurveyUI
//
// This Java source file is copyright (C) 2006 by Alan Kaminsky. All rights
// reserved. For further information, contact the author, Alan Kaminsky, at
// ark@cs.rit.edu.
//
// This Java source file is part of the M2MI Library ("The Library"). The
// Library is free software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the Free Software
// Foundation; either version 2 of the License, or (at your option) any later
// version.
//
// The Library is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// A copy of the GNU General Public License is provided in the file gpl.txt. You
// may also obtain a copy of the GNU General Public License on the World Wide
// Web at http://www.gnu.org/licenses/gpl.html or by writing to the Free
// Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA.
//
//******************************************************************************

package edu.rit.survey;

import java.awt.Dimension;
import java.awt.Font;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;

/**
 * Class SurveyUI provides the UI for the online survey application.
 *
 * @author  Alan Kaminsky
 * @version 27-Mar-2006
 */
public class SurveyUI
	extends JFrame
	{

// Hidden constants.

	private static final int GAP = 10;

// Hidden data members.

	private JLabel mySurveyCount;
	private JComboBox mySurveyList;
	private JButton myNewButton;
	private JTextField myQuestion;
	private JTextField[] myVoteCount = new JTextField [SurveyState.NUM_ANSWERS];
	private JRadioButton[] myVote = new JRadioButton [SurveyState.NUM_ANSWERS];

	private SurveyUIListener myListener;

// Exported constructors.

	/**
	 * Construct a new survey UI. The UI is initially not visible; call
	 * <TT>setVisible(true)</TT> to make it visible.
	 */
	public SurveyUI()
		{
		super ("Online Survey");

		JPanel panela = new JPanel();
		add (panela);
		panela.setBorder (BorderFactory.createEmptyBorder (GAP, GAP, GAP, GAP));
		panela.setLayout (new BoxLayout (panela, BoxLayout.Y_AXIS));

		JPanel panelb = new JPanel();
		panela.add (panelb);
		panelb.setLayout (new BoxLayout (panelb, BoxLayout.X_AXIS));

		panelb.add (new JLabel ("Survey:"));

		panelb.add (Box.createHorizontalStrut (GAP));

		mySurveyList = new JComboBox();
		panelb.add (mySurveyList);
		mySurveyList.setEditable (false);
		mySurveyList.addActionListener (new ActionListener()
			{
			public void actionPerformed
				(ActionEvent event)
				{
				if (myListener != null)
					{
					myListener.setSurvey (mySurveyList.getSelectedIndex());
					}
				}
			});

		panelb.add (Box.createHorizontalStrut (GAP));

		mySurveyCount = new JLabel ("None available");
		panelb.add (mySurveyCount);

		panelb.add (Box.createHorizontalStrut (GAP));

		myNewButton = new JButton ("New...");
		panelb.add (myNewButton);
		myNewButton.addActionListener (new ActionListener()
			{
			public void actionPerformed
				(ActionEvent event)
				{
				if (myListener != null)
					{
					myListener.newSurvey();
					}
				}
			});

		panela.add (Box.createVerticalStrut (GAP));

		myQuestion = new JTextField (40);
		panela.add (myQuestion);
		Font oldfont = myQuestion.getFont();
		Font newfont = oldfont.deriveFont (Font.BOLD);
		myQuestion.setFont (newfont);
		myQuestion.setEditable (false);

		panela.add (Box.createVerticalStrut (GAP));

		for (int i = 0; i < SurveyState.NUM_ANSWERS; ++ i)
			{
			panelb = new JPanel();
			panela.add (panelb);
			panelb.setLayout (new BoxLayout (panelb, BoxLayout.X_AXIS));

			JTextField votecount = new JTextField (5);
			myVoteCount[i] = votecount;
			panelb.add (votecount);
			votecount.setFont (newfont);
			votecount.setEditable (false);
			votecount.setHorizontalAlignment (JTextField.RIGHT);
			Dimension dim = votecount.getPreferredSize();
			votecount.setMinimumSize (dim);
			votecount.setPreferredSize (dim);
			votecount.setMaximumSize (dim);

			panelb.add (Box.createHorizontalStrut (GAP));

			JRadioButton votebutton = new JRadioButton (" ");
			myVote[i] = votebutton;
			panelb.add (votebutton);
			votebutton.setEnabled (false);
			final int vote = i;
			votebutton.addActionListener (new ActionListener()
				{
				public void actionPerformed
					(ActionEvent event)
					{
					if (myListener != null)
						{
						myListener.setVote (vote);
						}
					}
				});

			panelb.add (Box.createHorizontalGlue());
			}

		pack();
		}

// Exported operations.

	/**
	 * Set a listener to be invoked when user input occurs in this survey UI.
	 * Any previous listener is replaced with the given listener.
	 *
	 * @param  listener  Listener. If null, no listener method will be called on
	 *                   user input.
	 */
	public void setListener
		(SurveyUIListener listener)
		{
		myListener = listener;
		}

	/**
	 * Add the given survey to this survey UI.
	 *
	 * @param  theSurveyState  Survey.
	 */
	public void addSurvey
		(SurveyState theSurveyState)
		{
		mySurveyList.addItem (theSurveyState);
		for (int i = 0; i < SurveyState.NUM_ANSWERS; ++ i)
			{
			myVote[i].setEnabled (true);
			}
		int n = mySurveyList.getItemCount();
		mySurveyCount.setText (n + " available");
		}

	/**
	 * Set the question and answers for this survey UI.
	 *
	 * @param  theSurveyState  Survey state object containing question and
	 *                         answers.
	 */
	public void setQuestionAnswers
		(SurveyState theSurveyState)
		{
		myQuestion.setText (theSurveyState.getQuestion());
		for (int i = 0; i < SurveyState.NUM_ANSWERS; ++ i)
			{
			myVote[i].setText (theSurveyState.getAnswer (i));
			}
		}

	/**
	 * Set the vote counts for this survey UI.
	 *
	 * @param  theSurveyState  Survey state object containing vote counts.
	 */
	public void setVoteCounts
		(SurveyState theSurveyState)
		{
		for (int i = 0; i < SurveyState.NUM_ANSWERS; ++ i)
			{
			myVoteCount[i].setText
				(Integer.toString (theSurveyState.getVoteCount (i)));
			}
		}

	/**
	 * Set the votes for this survey UI.
	 *
	 * @param  theSurveyVote  Survey vote object containing votes.
	 */
	public void setVotes
		(SurveyVote theSurveyVote)
		{
		for (int i = 0; i < SurveyState.NUM_ANSWERS; ++ i)
			{
			myVote[i].setSelected (theSurveyVote.isVoteFor (i));
			}
		}

	}
